@@ -1,10 +1,24 @@
-<?php // $Id: auth.php,v 1.11.2.3 2004/12/20 02:41:08 moodler Exp $ 
+<?php // $Id$ 
 
+$string['alternatelogin'] = 'Si vous spcifiez ici une URL here, elle sera utilise comme page de connexion pour ce site. La page doit contenir un formulaire dont la proprit &nbsp;action&nbsp; est <strong>$a</strong> et doit contenir les champs <strong>username</strong> et <strong>password</strong>.<br />Attention  donner une URL correcte, sans quoi vous risquez de ne plus pouvoir accder au site.<br />Pour utiliser la page de connexion par dfaut, laissez ce champ vide.';
+$string['alternateloginurl'] = 'URL de la page de connexion de rechange';
+$string['auth_cas_baseuri'] = 'Adresse URI du serveur CAS (ne rien mettre s\'il n\'y en a pas).<br />par exemple, si le serveur CAS rpond  l\'adresse &nbsp;host.domaine.fr/CAS/&nbsp;, la valeur  indiquer ici est &nbsp;CAS/&nbsp;.';
+$string['auth_cas_create_user'] = 'Veuillez activer cette option si vous voulez insrer dans la base de donnes de Moodle les utilisateurs authentifis par le CAS. Dans le cas contraire, seuls les utilisateurs dj prsents dans la base de donnes de Moodle pourront se connecter.';
+$string['auth_cas_enabled'] = 'Veuillez activer cette option si vous voulez utiliser l\'authentification CAS.';
+$string['auth_cas_hostname'] = 'Nom d\'hte du serveur,<br />par exemple&nbsp;: &nbsp;host.domaine.fr&nbsp;';
+$string['auth_cas_invalidcaslogin'] = 'Dsol, la connexion a chou&nbsp;! Vous n\'tes pas autoris  vous connecter  la plateforme.';
+$string['auth_cas_language'] = 'Langue choisie';
+$string['auth_cas_logincas'] = 'Accs par connexion scurise';
+$string['auth_cas_port'] = 'Port utilis par le serveur CAS';
+$string['auth_cas_server_settings'] = 'Configuration du serveur CAS';
+$string['auth_cas_text'] = 'Connection scurise';
+$string['auth_cas_version'] = 'Version du logiciel CAS';
+$string['auth_casdescription'] = 'Cette mthode utilise un serveur CAS (Central Authentication Service) pour authentifier les utilisateurs dans un environnement Single Sign On (SSO). Il est aussi possible d\'utiliser une simple authentification LDAP. Si le nom d\'utilisateur et le mot de passe donns sont valides suivant le CAS, Moodle cre un nouvel utilisateur dans sa base de donnes, en hritant si ncessaire des attributs LDAP de l\'utilisateur. Lors des connexions ultrieures, seuls le nom d\'utilisateur et le mot de passe sont vrifis.';
+$string['auth_castitle'] = 'Utiliser un serveur CAS (SSO)';
 $string['auth_common_settings'] = 'Rglages communs';
 $string['auth_data_mapping'] = 'Appariement des donnes';
-$string['auth_data_mapping'] = 'Data mapping';
 $string['auth_dbdescription'] = 'Cette mthode utilise une base de donnes externe afin de vrifier qu\'un nom d\'utilisateur et son mot de passe sont valides. Si le compte concern est nouveau, il est possible de copier des donnes provenant de certains champs vers Moodle.';
-$string['auth_dbextrafields'] = 'Ces zones sont facultatives. Il vous est possible de remplir certains champs de Moodle avec des donnes provenant des <strong>champs de la base de donnes externe</strong>.<p>Si vous laissez ces zones vides, les valeurs par dfaut seront utilises.<p>Dans tous les cas, l\'utilisateur a la possibilit de modifier tous ces champs, une fois connect.';
+$string['auth_dbextrafields'] = '<p>Ces zones sont facultatives. Il vous est possible de remplir certains champs de Moodle avec des donnes provenant des <strong>champs de la base de donnes externe</strong>.</p><p>Si vous laissez ces zones vides, les valeurs par dfaut seront utilises.</p><p>Dans tous les cas, l\'utilisateur a la possibilit de modifier tous ces champs, une fois connect.</p>';
 $string['auth_dbfieldpass'] = 'Nom du champ contenant les mots de passe';
 $string['auth_dbfielduser'] = 'Nom du champ contenant les noms d\'utilisateurs';
 $string['auth_dbhost'] = 'Ordinateur hbergeant la base de donnes';
@@ -15,8 +29,6 @@ $string['auth_dbtable'] = 'Nom de la table dans la base de donnes';
 $string['auth_dbtitle'] = 'Utiliser une base de donnes externe';
 $string['auth_dbtype'] = 'Type de la base de donnes (Pour plus d\'information, voir la <a href=\'../lib/adodb/readme.htm#drivers\'>documentation de ADOdb</a>)';
 $string['auth_dbuser'] = 'Compte avec accs en lecture  la base de donnes';
-$string['auth_editlock_expl'] = '<p><strong>Verrouiller cette valeur&nbsp;:</strong> si cette option est active, elle empchera les utilsateurs et les administrateurs de modifier le champ directement. Utilisez cette option si vous maintenez ces donnes dans le systme d\'authentification externe.</p>';
-$string['auth_editlock'] = 'Verrouiller cette valeur';
 $string['auth_emaildescription'] = 'La confirmation par courriel est la mthode d\'authentification par dfaut. Lorsqu\'un utilisateur s\'enregistre en choisissant ses nom d\'utilisateur et mot de passe, un message de confirmation est envoy  son adresse de courriel. Ce message contient un lien scuris vers une page Web o il peut confirmer son inscription. Les connexions suivantes ne vrifient que les nom d\'utilisateur et mot de passe prcdemment enregistrs dans la base de donnes de Moodle.';
 $string['auth_emailtitle'] = 'Authentification par courriel';
 $string['auth_fccreators'] = 'Liste des groupes dont les membres ont l\'autorisation de crer de nouveaux cours. Sparez les diffrents groupes par des points-virgules (;). Les noms doivent tre transcrits exactement tels qu\'ils sont sur le serveur FirstClass. La casse des caractres doit tre respecte.';
@@ -26,6 +38,8 @@ $string['auth_fchost'] = 'L\'adresse du serveur FirstClass. Indiquez l\'adresse
 $string['auth_fcpasswd'] = 'Mot de passe du compte FirstClass ayant le privilge  Subadministrator .';
 $string['auth_fctitle'] = 'Utilisation d\'un serveur FirstClass';
 $string['auth_fcuserid'] = 'Numro d\'identification du compte FirstClass ayant le privilge  Subadministrator .';
+$string['auth_fieldlock_expl'] = '<p><strong>Verrouiller cette valeur&nbsp;:</strong> si cette option est active, elle empchera les utilisateurs et les administrateurs de modifier le champ directement. Utilisez cette option si vous maintenez ces donnes dans le systme d\'authentification externe.</p>';
+$string['auth_fieldlock'] = 'Verrouiller cette valeur';
 $string['auth_imapdescription'] = 'Cette mthode utilise un serveur IMAP pour vrifier qu\'un nom d\'utilisateur et son mot de passe sont valides.';
 $string['auth_imaphost'] = 'Adresse du serveur IMAP. Utiliser l\'adresse IP et non le nom de la machine.';
 $string['auth_imapport'] = 'Numro de port du serveur IMAP. Il s\'agit gnralement de 143 ou 993.';
@@ -39,16 +53,16 @@ $string['auth_ldap_create_context'] = 'Lors de l\'utilisation de la cration d\'u
 $string['auth_ldap_creators'] = 'Liste des groupes dont les membres ont le droit de crer des cours. Les groupes (en gnral, de la forme  cn=teachers,ou=staff,o=myorg ) sont spars par des points-virgules (;).';
 $string['auth_ldap_expiration_desc'] = 'Si vous voulez dsactiver le contrle d\'chance des mots de passe, indiquez Non. Si vous indiquez LDAP, la dure sera reprise automatiquement de la variable passwordexpiration du serveur LDAP';
 $string['auth_ldap_expiration_warning_desc'] = 'Nombre de jours avant que l\'avertissement d\'chance soit affich.';
-$string['auth_ldap_expireattr_desc'] = 'Facultatif : ne pas tenir compte de l\'attribut ldap contenant la dure d\'chance du mot de passe PasswordExpirationTime';
+$string['auth_ldap_expireattr_desc'] = 'Facultatif : ne pas tenir compte de l\'attribut ldap contenant la dure d\'chance du mot de passe passwordExpirationTime';
 $string['auth_ldap_graceattr_desc'] = 'Facultatif : ne pas tenir compte de l\'attribut gracelogin';
 $string['auth_ldap_gracelogins_desc'] = 'Activer le support du gracelogin LDAP. Une fois le mot de passe chu, l\'utilisateur peut se connecter jusqu\' ce que le paramtre gracelogin ait une valeur de 0. L\'activation de ce rglage affiche un message explicite lorsque le mot de passe est chu.';
-$string['auth_ldap_host_url'] = 'Indiquer le serveur LDAP sous form d\'URL comme ceci :<br /> ldap://ldap.organisation.fr/ <br />ou&nbsp;:<br /> ldaps://ldap.organisation.fr/ . Si vous utilisez plusieurs serveurs LDAP par scurit, sparez leurs adresses avec des points-virgules (;).';
+$string['auth_ldap_host_url'] = 'Indiquer le serveur LDAP sous forme d\'URL comme ceci :<br /> ldap://ldap.organisation.fr/ <br />ou&nbsp;:<br /> ldaps://ldap.organisation.fr/ . Si vous utilisez plusieurs serveurs LDAP par scurit, sparez leurs adresses avec des points-virgules (;).';
 $string['auth_ldap_login_settings'] = 'Configuration de la connexion';
 $string['auth_ldap_memberattribute'] = 'Indiquer l\'attribut d\'appartenance  un groupe. D\'habitude cet attribut est  member .';
-$string['auth_ldap_objectclass'] = 'Le filtre utilis pour rechercher/renommer des utilisateurs. On y mettra d\'habitude quelque chose comme objectClass=posixAccount. La valeur par dfaut est objectClass=*, ce que retournera tous les objets du serveur LDAP.';
+$string['auth_ldap_objectclass'] = 'Le filtre utilis pour rechercher/renommer des utilisateurs. On y mettra d\'habitude quelque chose comme objectClass=posixAccount. La valeur par dfaut est objectClass=*, ce qui retournera tous les objets du serveur LDAP.';
 $string['auth_ldap_opt_deref'] = 'Dtermine le traitement des alias durant la recherche. Veuillez slectionner une des valeurs suivantes&nbsp;: &nbsp;Non&nbsp; (LDAP_DEREF_NEVER) ou &nbsp;Oui&nbsp; (LDAP_DEREF_ALWAYS)';
 $string['auth_ldap_passwdexpire_settings'] = 'Rglages de l\'chance du mot de passe LDAP.';
-$string['auth_ldap_search_sub'] = 'Mettre une valeur diffrente de 0 pour rechercher les enregistrements dans les sous-contextes.';
+$string['auth_ldap_search_sub'] = 'Rechercher les utilsateurs dans les sous-contextes.';
 $string['auth_ldap_server_settings'] = 'Configuration du serveur LDAP';
 $string['auth_ldap_update_userinfo'] = 'Mettre  jour les donnes des utilisateurs (prnom, nom, adresse, etc.) de Moodle depuis l\'annuaire LDAP. Lire  /auth/ldap/attr_mappings.php  pour avoir des informations sur la correspondance.';
 $string['auth_ldap_user_attribute'] = 'L\'attribut utilis pour nommer et rechercher les utilisateurs. Habituellement  cn .';
@@ -56,7 +70,7 @@ $string['auth_ldap_user_settings'] = 'Configuration de la consultation utilisate
 $string['auth_ldap_user_type'] = 'Indiquer comment les utilisateurs sont enregistrs dans LDAP. Ce rglage permet galement d\'indiquer comment l\'chance des comptes (mot de passe) et la cration des utilisateurs fonctionnera.';
 $string['auth_ldap_version'] = 'La version du protocole LDAP que votre serveur utilise.';
 $string['auth_ldapdescription'] = 'Cette mthode permet l\'authentification auprs d\'un annuaire LDAP externe. Si les nom d\'utilisateur et mot de passe sont corrects, Moodle crera un nouvel enregistrement pour cet utilisateur dans sa base de donnes. Ce module peut rcuprer les attributs de l\'enregistrement LDAP de l\'utilisateur afin de remplir certains champs dans Moodle. Lors des connexions suivantes, seuls les nom d\'utilisateur et mot de passe sont vrifis.';
-$string['auth_ldapextrafields'] = 'Ces zones sont facultatives. Il vous est possible de remplir certains champs de Moodle avec des donnes provenant des <strong>attributs de l\'annuaire LDAP</strong>.<p>Si vous laissez ces zones vides, aucune donne ne sera rcupre de l\'annuaire LDAP et les valeurs par dfaut de Moodle seront utilises. <p>Dans tous les cas, l\'utilisateur a la possibilit de modifier tous ces champs, une fois connect.';
+$string['auth_ldapextrafields'] = '<p>Ces zones sont facultatives. Il vous est possible de remplir certains champs de Moodle avec des donnes provenant des <strong>attributs de l\'annuaire LDAP</strong>.</p><p>Si vous laissez ces zones vides, aucune donne ne sera rcupre de l\'annuaire LDAP et les valeurs par dfaut de Moodle seront utilises.</p><p>Dans tous les cas, l\'utilisateur a la possibilit de modifier tous ces champs, une fois connect.</p>';
 $string['auth_ldaptitle'] = 'Utiliser un serveur LDAP';
 $string['auth_manualdescription'] = 'Cette mthode supprime pour les utilisateurs le droit de crer eux-mmes leur compte. Tous les comptes doivent tre crs par l\'administrateur.';
 $string['auth_manualtitle'] = 'Cration manuelle de comptes';
@@ -68,19 +82,31 @@ $string['auth_nntptitle'] = 'Utiliser un serveur NNTP';
 $string['auth_nonedescription'] = 'Les utilisateurs peuvent s\'enregistrer et crer des comptes valides immdiatement sans aucune authentification ni confirmation par courriel. Attention ! Lors de l\'utilisation de cette mthode, bien penser  toutes les implications (problmes d\'administration et scurit).';
 $string['auth_nonetitle'] = 'Pas d\'authentification';
 $string['auth_pamdescription'] = 'Cette mthode utilise PAM pour accder aux noms d\'utilisateurs natifs sur ce serveur. Pour utiliser ce module, vous devrez installer le logiciel <a href=\"http://www.math.ohio-state.edu/~ccunning/pam_auth/\" target=\"_blank\">PHP4 PAM Authentication</a>.';
-$string['auth_pamtitle'] = 'PAM (Pluggable Authentication Modules = Modules d\'authentification installables)';
-$string['auth_passwordwillexpire'] = 'Votre mot de passe arrivera  chance dans $a jours. Voulez-vous changer votre mot de passe maintenant ?';
+$string['auth_pamtitle'] = 'PAM (Modules d\'authentification installables)';
 $string['auth_passwordisexpired'] = 'Votre mot de passe est chu. Voulez-vous le changer maintenant ?';
+$string['auth_passwordwillexpire'] = 'Votre mot de passe arrivera  chance dans $a jours. Voulez-vous changer votre mot de passe maintenant ?';
 $string['auth_pop3description'] = 'Cette mthode utilise un serveur POP3 pour vrifier qu\'un nom d\'utilisateur et son mot de passe sont valides.';
 $string['auth_pop3host'] = 'L\'adresse du serveur POP3. Utiliser l\'adresse IP et non le nom de la machine.';
 $string['auth_pop3mailbox'] = 'Nom de la bote aux lettres vers laquelle tenter la connexion, d\'habitude &nbsp;INBOX .';
 $string['auth_pop3port'] = 'Numro de port du serveur POP3. Il s\'agit habituellement du port 110, et lors de l\'utilisation de SSL du port 995.';
 $string['auth_pop3title'] = 'Utiliser un serveur POP3';
 $string['auth_pop3type'] = 'Type de serveur. Si le serveur POP3 utilise  certificate security , choisir  pop3cert .';
+$string['auth_shib_convert_data_description'] = 'Vous pouvez utiliser cette API pour modifier les donnes fournies par Shibboleth. Lisez le fichier <a href=\"../auth/shibboleth/README.txt\" target=\"_blank\">README</a> pour d\'autres instructions.';
+$string['auth_shib_convert_data_warning'] = 'Le fichier n\'existe pas ou n\'est pas accessible en lecture par le serveurweb&nbsp;!';
+$string['auth_shib_convert_data'] = 'API de modification de donnes';
+$string['auth_shib_instructions_help'] = 'Vous pouvez indiquer ici des instructions pour expliquer le fonctionnement de Shibboleth  vos utilisateurs. Ces instructions seront affiches sur la page de connexion, dans la zone adquate. Le texte devrait contenir un lien vers une ressource protge par Shibboleth, redirigeant les utilisateurs vers &nbsp;<b>$a</b>&nbsp; afin de permettre aux utilisateurs de se connecter  Moodle. Si vous laissez ce champ vide, les instructions standard (sans information sur Shibboleth) seront utilises';
+$string['auth_shib_instructions'] = 'Utilisez la <a href=\"$a\">connexion Shibboleth</a> pour accder via Shibboleth, si votre institution le permet.<br />Sinon, utilisez la connexion standard de ce formulaire.';
+$string['auth_shib_only_description'] = 'Cocher cette option pour imposer l\'authentiication Shibboleth';
+$string['auth_shib_only'] = 'Seulement Shibboleth';
+$string['auth_shib_username_description'] = 'Nom de la variable d\'environement du serveur web Shibboleth  utiliser comme nom d\'utilisateur Moodle';
+$string['auth_shibboleth_login'] = 'Connexion Shibboleth';
+$string['auth_shibboleth_manual_login'] = 'Connexion manuelle';
+$string['auth_shibbolethdescription'] = 'Cette mthode permet de crer et d\'authentifier des utilisateurs par l\'intermdiaire d\'un serveur <a href=\"http://shibboleth.internet2.edu/\" target=\"_blank\">Shibboleth</a>.<br />Veuillez lire attentivement le fichier <a href=\"../auth/shibboleth/README.txt\" target=\"_blank\">README</a> pour apprendre comment configurer Moodle pour authentification Shibboleth';
+$string['auth_shibbolethtitle'] = 'Shibboleth';
 $string['auth_updatelocal_expl'] = '<p><strong>Mise  jour des donnes locales&nbsp;:</strong> lorsque cette option est active, le champ est mis  jour (depuis la source externe) chaque fois que l\'utilisateur se connecte ou qu\'une synchronisation a lieu. Les champs destins  tre mis  jour ainsi devraient tre verrouills.</p>';
 $string['auth_updatelocal'] = 'Mise  jour des donnes locales';
 $string['auth_updateremote_expl'] = '<p><strong>Mise  jour des donnes externes&nbsp;:</strong> lorsque cette option est active, la source d\'authentification externe est mise  jour chaque fois que les donnes de l\'utilisateur le sont. Pour permettre leur modification, les champs devraient tre dverrouills.</p>';
-$string['auth_updateremote_ldap'] = '<p><strong>Remarque&nbsp;:</strong> la mise  jour externe des donnes LDAP ncessite de fixer pour tous les enregistrements les valeurs binddn et bindpw  un utilisateur-lien avec des privilges de modification. Elle ne conserve pas les attributs  plusieurs valeurs multi-valued attributes et supprimera les valeurs en trop lors des mises  jour.</p>';
+$string['auth_updateremote_ldap'] = '<p><strong>Remarque&nbsp;:</strong> la mise  jour externe des donnes LDAP ncessite de fixer pour tous les enregistrements les valeurs binddn et bindpw  un utilisateur-lien avec des privilges de modification. Elle ne conserve pas les attributs  plusieurs valeurs et supprimera les valeurs en trop lors des mises  jour.</p>';
 $string['auth_updateremote'] = 'Mise  jour des donnes externes';
 $string['auth_user_create'] = 'Activer la cration des utilisateurs';
 $string['auth_user_creation'] = 'Les nouveaux utilisateurs (anonymes) peuvent crer des comptes sur la source d\'authentification externe, avec confirmation par courriel. Ne pas oublier de configurer les ventuelles options dans les diffrents modules lors de l\'activation de cette possibilit.';
@@ -90,16 +116,23 @@ $string['authinstructions'] = 'Il vous est possible de fournir ici des instructi
 $string['changepassword'] = 'URL de la page de changement du mot de passe';
 $string['changepasswordhelp'] = 'Vous pouvez indiquer dans cette zone l\'URL d\'une page sur laquelle vos utilisateurs pourront rcuprer ou changer leurs nom d\'utilisateur et mot de passe s\'ils les ont oublis. Cette URL sera disponible sous forme d\'un bouton sur la page de connexion. Si cette zone est vide, ce bouton ne sera pas affich.';
 $string['chooseauthmethod'] = 'Choisir une mthode d\'authentification';
-$string['forcechangepasswordfirst_help'] = 'Impose aux utilisateurs de changer leur mot de passe lors de leur prochaine connexion  Moodle.';
 $string['forcechangepassword_help'] = 'Impose aux utilisateurs de changer leur mot de passe lors de leur premire connexion  Moodle.';
 $string['forcechangepassword'] = 'Imposer le changement du mot de passe';
+$string['forcechangepasswordfirst_help'] = 'Impose aux utilisateurs de changer leur mot de passe lors de leur prochaine connexion  Moodle.';
 $string['guestloginbutton'] = 'Bouton de connexion anonyme';
 $string['instructions'] = 'Instructions';
+$string['locked'] = 'Verrouill';
 $string['md5'] = 'Cryptage MD5';
 $string['plaintext'] = 'Texte en clair';
 $string['showguestlogin'] = 'Vous pouvez choisir d\'afficher ou non le bouton de connexion en tant qu\'utilisateur anonyme sur la page de connexion.';
 $string['stdchangepassword_expl'] = 'Si la source d\'authentification externe permet le changement de mot de passe par l\'intermdaire de Moodle, mettez cette rglage sur &nbsp;Oui&nbsp;. Ce rglage rend obsolte le rglage &nbsp;URL de la page de changement du mot de passe&nbsp;.';
 $string['stdchangepassword_explldap'] = 'Remarque&nbsp;: il est recommand d\'utiliser LDAP  travers un tunnel chiffr SSL (ldaps://) si le serveur LDAP n\'est pas dans un intranet.';
 $string['stdchangepassword'] = 'Utiliser la page de changement de mot de passe standard';
+$string['unlocked'] = 'Dverrouill';
+$string['unlockedifempty'] = 'Dverrouill si vide';
+$string['update_never']    = 'Jamais';
+$string['update_oncreate'] = ' la cration';
+$string['update_onlogin']  = ' chaque connexion';
+$string['update_onupdate']  = 'Lors de la mise  jour';
 
 ?>
