@@ -1,5 +1,5 @@
 <?PHP // $Id$ 
-      // error.php - created with Moodle 1.4 development (2004080300)
+      // error.php - created with Moodle 1.4.3 + (2004083132)
 
 
 $string['coursegroupunknown'] = ',   $a  ';
@@ -9,12 +9,12 @@ $string['filenotfound'] = ',       ';
 $string['groupalready'] = '     $a';
 $string['groupunknown'] = ' $a     ';
 $string['invalidfieldname'] = '\"$a\"   ';
-$string['missingfield'] = ' ';
+$string['missingfield'] = '  \"$a\"';
 $string['modulerequirementsnotmet'] = ' \"$a->modulename\" ($a->moduleversion)    .       (   $a->currentmoodle,     $a->requiremoodle).';
 $string['notavailable'] = '   .';
 $string['restricteduser'] = ',     \"$a\"     .';
 $string['unknowncourse'] = '   ';
-$string['usernotaddederror'] = ' ';
+$string['usernotaddederror'] = ' \"$a\"   -  ';
 $string['usernotaddedregistered'] = ' \"$a\"   -  ';
 $string['usernotavailable'] = '      .';
 
